@@ -25,21 +25,21 @@ EOF
 }
 
 tests=(
-examples/cpu_cnn_inference_f32.c
-examples/cpu_cnn_inference_f32.cpp
-#examples/cpu_cnn_inference_int8.cpp
-#examples/cpu_cnn_training_bf16.cpp
+examples/cnn_inference_f32.c
+examples/cnn_inference_f32.cpp
+examples/cnn_inference_int8.cpp
+examples/cnn_training_f32.cpp
+examples/cpu_cnn_training_bf16.cpp
 examples/cpu_cnn_training_f32.c
-examples/cpu_cnn_training_f32.cpp
-examples/cpu_getting_started.cpp
-examples/cpu_memory_format_propagation.cpp
-examples/cpu_performance_profiling.cpp
 examples/cpu_rnn_inference_f32.cpp
-#examples/cpu_rnn_inference_int8.cpp
-examples/cpu_rnn_training_f32.cpp
-#examples/gpu_getting_started.c
-#examples/gpu_getting_started.cpp
+examples/cpu_rnn_inference_int8.cpp
+#examples/cross_engine_reorder.c
+#examples/cross_engine_reorder.cpp
+examples/getting_started.cpp
 #examples/gpu_opencl_interop.cpp
+examples/memory_format_propagation.cpp
+examples/performance_profiling.cpp
+examples/rnn_training_f32.cpp
 )
 
 case "$1" in
